@@ -173,6 +173,8 @@ if ($do==1) {
          "CGI_Script|$cygloc\\script\\fullautoapi_fastcgi.pl -e\',". 
          "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
          "/commit:apphost",'__display__');
+      ($stdout,$stderr)=$handle->cwd("~");
+      ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/script",'__display__');
       ($stdout,$stderr)=$handle->cwd("~/FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("touch CGI_Script");
       #
@@ -193,7 +195,6 @@ cd bin
 END
       ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script");
       ($stdout,$stderr)=$handle->cwd("~");
-      #($stdout,$stderr)=$handle->cmd("iisreset /start",'__display__');
    }
    ###############
    ## RABBITMQ
@@ -1380,7 +1381,7 @@ END
       "./script/fullautoapi_create.pl controller User",'__display__');
    ($stdout,$stderr)=$handle->cmd("mv lib/FullAutoAPI/Controller/User.pm ".
       "lib/FullAutoAPI/Controller/User.bak");
-   my $view_path='./FullAutoAPI/View/TT.pm';
+   my $view_path='./lib/FullAutoAPI/View/TT.pm';
    ($stdout,$stderr)=$handle->cmd(
       "./script/fullautoapi_create.pl view TT TT",'__display__');
    $ad='    WRAPPER => %SQ%wrapper.tt%SQ%,%NL%';
